import os
import yaml
from typing import Dict

class ETOptions:
    def __init__(self, options: Dict):
        self.options = options


def et_options_constructor(loader, node):
    """
    Returns a dict of values written in et_options.yaml file
    in the client/fe project.
    """
    values = loader.construct_mapping(node)
    et_options_obj: ETOptions = ETOptions(values)
    return et_options_obj


def etoptions_representer(dumper, data: ETOptions):
    return dumper.represent_mapping('!ETOptions', {k: v for k, v in data.options.items()})


def parse_et_options_yaml(file_path):
    if not os.path.exists(file_path):
        return {}
    with open(file_path, 'r') as file:
        data = yaml.safe_load(file)
    return data

def get_et_options_as_string(user_file_path: str):
    yaml.SafeLoader.add_constructor('!ETOptions', et_options_constructor)
    et_options_data = parse_et_options_yaml(user_file_path)
    if not et_options_data:
        return ""
    to_be_returned = ""
    for k, v in et_options_data[0].options.items():
        to_be_returned += f"{k} {v}\n"
    return to_be_returned

def create_et_options(project_path):
    yaml.add_representer(ETOptions, etoptions_representer)
    et_options = ETOptions(options={'SkipRows': '1', 'Delimiter': "','", 'DateDelim': "'-'", 'MaxErrors': '0'})
    with open(f"{project_path}/et_options.yml", "w") as file:
        yaml.dump([et_options], file, default_flow_style=False)



from dataclasses import dataclass, field
from typing import Optional, Type, TypeVar
from dbt.adapters.base.relation import BaseRelation, Policy, Path, InformationSchema
from dbt.adapters.contracts.relation import ComponentName, RelationType

@dataclass
class NetezzaPath(Path):
    def get_part(self, key: ComponentName) -> Optional[str]:
        if key == ComponentName.Database:
            if self.database is None:
                return self.database
            return self.database.replace('"', "")
        elif key == ComponentName.Schema:
            if self.schema is None:
                return None
            return self.schema
        elif key == ComponentName.Identifier:
            if self.identifier is None:
                return None
            return self.identifier
        else:
            raise ValueError(
                "Got a key of {}, expected one of {}".format(key, list(ComponentName))
            )

@dataclass
class NetezzaQuotePolicy(Policy):
    database: bool = True
    schema: bool = True
    identifier: bool = True


@dataclass(frozen=True, eq=False, repr=False)
class NetezzaRelation(BaseRelation):
    path: NetezzaPath
    quote_policy: Policy = field(default_factory=lambda: NetezzaQuotePolicy())

    def _is_exactish_match(self, field: ComponentName, value: str) -> bool:
        # Remove requirement for dbt_created due to dbt bug with cache preservation
        # of that property
        if self.quote_policy.get_part(field) is False:
            return self.path.get_lowered_part(field) == value.lower()
        else:
            return self.path.get_part(field) == value.replace('"', "")

    @staticmethod
    def add_ephemeral_prefix(name: str):
        # Netezza reserves '_' name prefix for system catalogs
        return f"dbt__cte__{name}"

    def information_schema(self, view_name=None) -> "NetezzaInformationSchema":
        # some of our data comes from jinja, where things can be `Undefined`.
        if not isinstance(view_name, str):
            view_name = None

        # Kick the user-supplied schema out of the information schema relation
        # Instead address this as <database>.information_schema by default
        info_schema = NetezzaInformationSchema.from_relation(self, view_name)
        return info_schema.incorporate(path={"schema": None})

Info = TypeVar("Info", bound="NetezzaInformationSchema")

class NetezzaInformationSchema(InformationSchema):
    @classmethod
    def get_path(cls, relation: NetezzaRelation, information_schema_view: Optional[str]) -> NetezzaPath:
        return Path(
            database=relation.database.replace('"', ""),
            schema=relation.schema,
            identifier="INFORMATION_SCHEMA",
        )

    @classmethod
    def from_relation(
        cls: Type[Info],
        relation: NetezzaRelation,
        information_schema_view: Optional[str],
    ) -> Info:
        include_policy = cls.get_include_policy(relation, information_schema_view)
        quote_policy = cls.get_quote_policy(relation, information_schema_view)
        path = cls.get_path(relation, information_schema_view)
        return cls(
            type=RelationType.View,
            path=path,
            include_policy=include_policy,
            quote_policy=quote_policy,
            information_schema_view=information_schema_view,
        )



from dbt.adapters.base.column import Column
from dataclasses import dataclass


@dataclass
class NetezzaColumn(Column):
    TYPE_LABELS = {
        **Column.TYPE_LABELS,
        "STRING": "varchar(2000)",
    }

    # Override to ignore data type length
    def is_string(self) -> bool:
        return self.dtype.lower() == "text" or any(
            self.dtype.lower().startswith(dtype)
            for dtype in ["char", "nchar", "varchar", "nvarchar"]
        )

    # Override to ignore data type precision
    def is_numeric(self) -> bool:
        return any(
            self.dtype.lower().startswith(dtype) for dtype in ["numeric", "decimal"]
        )



import os

import pytz
import agate
from dateutil import parser
from datetime import datetime
from dataclasses import dataclass
from typing import Optional, List, Dict, Tuple, Any, Union

from dbt import deprecations
from dbt.adapters.base.connections import AdapterResponse
from dbt.adapters.base.meta import available
from dbt.adapters.base.impl import ConstraintSupport, _utc
from dbt.adapters.base.relation import BaseRelation
from dbt.adapters.exceptions.database import UnexpectedDbReferenceError
from dbt.adapters.netezza import NetezzaConnectionManager
from dbt.adapters.netezza.column import NetezzaColumn
from dbt.adapters.netezza.et_options_parser import get_et_options_as_string
from dbt.adapters.netezza.relation import NetezzaRelation
from dbt.adapters.protocol import AdapterConfig
from dbt.adapters.sql.impl import SQLAdapter, LIST_RELATIONS_MACRO_NAME
from dbt.contracts.graph.manifest import Manifest
from dbt_common.exceptions import CompilationError, DbtDatabaseError, MacroResultError
from dbt_common.utils import filter_null_values, AttrDict
from dbt.contracts.graph.nodes import ConstraintType
from dbt.adapters.contracts.macros import MacroResolverProtocol

@dataclass
class NetezzaConfig(AdapterConfig):
    dist: Optional[str] = None


FRESHNESS_MACRO_NAME = "collect_freshness"  # Macro used to analyze the freshness of the data imports in tables
class NetezzaAdapter(SQLAdapter):
    INT_MIN32 = -2147483648
    INT_MAX32 = 2147483648

    AdapterSpecificConfigs = NetezzaConfig
    ConnectionManager = NetezzaConnectionManager
    Relation = NetezzaRelation
    Column = NetezzaColumn

    CONSTRAINT_SUPPORT = {
        ConstraintType.check: ConstraintSupport.NOT_ENFORCED,
        ConstraintType.not_null: ConstraintSupport.ENFORCED,
        ConstraintType.unique: ConstraintSupport.NOT_ENFORCED,
        ConstraintType.primary_key: ConstraintSupport.NOT_ENFORCED,
        ConstraintType.foreign_key: ConstraintSupport.NOT_ENFORCED,
    }

    @classmethod
    def date_function(cls):
        return "now()"

    # Overriding methods because Netezza uppercases by default
    # and we want to avoid quoting of columns
    # Source: https://github.com/dbt-labs/dbt-snowflake/blob/fda11c2e822519996101d2c456a51570f4ed1c04/dbt/adapters/snowflake/impl.py#L45-L54
    @classmethod
    def _catalog_filter_table(
        cls, table: agate.Table, manifest: Manifest
    ) -> agate.Table:
        lowered = table.rename(column_names=[c.lower() for c in table.column_names])
        return super()._catalog_filter_table(lowered, manifest)

    # Source: https://github.com/dbt-labs/dbt-snowflake/blob/fda11c2e822519996101d2c456a51570f4ed1c04/dbt/adapters/snowflake/impl.py#L56-L69
    def _make_match_kwargs(self, database: str, schema: str, identifier: str):
        quoting = self.config.quoting
        if identifier is not None and quoting["identifier"] is False:
            identifier = identifier.upper()

        if schema is not None and quoting["schema"] is False:
            schema = schema.upper()

        if database is not None and quoting["database"] is False:
            database = database.upper()

        return filter_null_values(
            {"identifier": identifier, "schema": schema, "database": database}
        )

    # Source: https://github.com/dbt-labs/dbt-snowflake/blob/fda11c2e822519996101d2c456a51570f4ed1c04/dbt/adapters/snowflake/impl.py#L128-L166
    def list_relations_without_caching(
        self, schema_relation: BaseRelation
    ) -> List[BaseRelation]:
        kwargs = {"schema_relation": schema_relation}
        try:
            results = self.execute_macro(LIST_RELATIONS_MACRO_NAME, kwargs=kwargs)
        except DbtDatabaseError as exc:
            # if the schema doesn't exist, we just want to return.
            # Alternatively, we could query the list of schemas before we start
            # and skip listing the missing ones, which sounds expensive.
            if "Object does not exist" in str(exc):
                return []
            raise

        relations: List[BaseRelation] = []
        quote_policy = {"database": True, "schema": True, "identifier": True}

        columns = ["DATABASE", "SCHEMA", "NAME", "TYPE"]
        for _database, _schema, _identifier, _type in results.select(columns):
            try:
                _type = self.Relation.get_relation_type(_type.lower())
            except ValueError:
                _type = self.Relation.External
            relations.append(
                self.Relation.create(
                    database=_database,
                    schema=_schema,
                    identifier=_identifier,
                    quote_policy=quote_policy,
                    type=_type,
                )
            )

        return relations

    # Override with Redshift implementation because Netezza does not support `text`
    # Source: https://github.com/dbt-labs/dbt-redshift/blob/64f6f7ba4f8fbe11d9c547f7c07faeb9b14deb83/dbt/adapters/redshift/impl.py#L54-L61
    @classmethod
    def convert_text_type(cls, agate_table, col_idx):
        column = agate_table.columns[col_idx]
        # `lens` must be a list, so this can't be a generator expression,
        # because max() raises an exception if its argument has no members.
        # source: https://github.com/fishtown-analytics/dbt/pull/2255/files#diff-39545f1198b754f67de59957630a527b6d1df026aff22cc90de923f5653d5ad8
        lens = [len(d.encode("utf-8")) for d in column.values_without_nulls()]
        max_len = max(lens) if lens else 64
        return f"varchar({max_len})"

    # Override to remove `without time zone` because Netezza does not support this
    @classmethod
    def convert_datetime_type(cls, agate_table: agate.Table, col_idx: int) -> str:
        return "timestamp"

    # Override to check if view exists before dropping because Netezza does not support
    # `drop view if exists`
    def drop_relation(self, relation):
        if relation.type == "view":
            identifier = relation.identifier
            relations = self.list_relations_without_caching(relation)
            no_relation_exists = (
                next(
                    rel
                    for rel in relations
                    if rel.type == "view" and rel.identifier == identifier
                )
                is None
            )
            if no_relation_exists:
                return

        super().drop_relation(relation)

    # Override to skip the cursor.commit() which causes a ODBC HY010
    # "function sequence error"
    # Source: https://github.com/dbt-labs/dbt-core/blob/c270a77552ae9fc66fdfab359d65a8db1307c3f3/core/dbt/adapters/sql/impl.py#L223-L243
    def run_sql_for_tests(self, sql, fetch, conn):
        cursor = conn.handle.cursor()
        try:
            cursor.execute(sql)
            if hasattr(conn.handle, "commit"):
                # Skip cursor.commit()
                pass
            if fetch == "one":
                return cursor.fetchone()
            elif fetch == "all":
                return cursor.fetchall()
            else:
                return
        except BaseException as e:
            if conn.handle and not getattr(conn.handle, "closed", True):
                conn.handle.rollback()
            print(sql)
            print(e)
            raise
        finally:
            conn.transaction_open = False

    @available
    def get_seed_file_path(self, model) -> str:
        return os.path.join(model["root_path"], model["original_file_path"])

    @available
    def verify_database(self, database):
        if database.startswith('"'):
            database = database.strip('"')
        expected = self.config.credentials.database
        if database.lower() != expected.lower():
            raise UnexpectedDbReferenceError(self.type(), database, expected)
        # return an empty string on success so macros can call this
        return ""

    @available
    def rename_relation(self, from_relation, to_relation):
        self.cache_renamed(from_relation, to_relation)

        kwargs = {"from_relation": from_relation, "to_relation": to_relation}
        self.execute_macro('rename_relation', kwargs=kwargs)

    @available
    def get_et_options(self, model) -> str:
        return get_et_options_as_string(os.path.join(model["root_path"], "et_options.yml"))

    # Override to change the default value of quote_columns to False
    # Source: https://github.com/dbt-labs/dbt-core/blob/7f8d9a7af976f640e376900773a0d793acf3a3ce/core/dbt/adapters/base/impl.py#L812-L828
    @available
    def quote_seed_column(self, column: str, quote_config: Optional[bool]) -> str:
        # Change default value to False
        quote_columns: bool = False
        if isinstance(quote_config, bool):
            quote_columns = quote_config
        elif quote_config is None:
            pass
        else:
            raise CompilationError(
                f'The seed configuration value of "quote_columns" has an '
                f"invalid type {type(quote_config)}"
            )

        if quote_columns:
            return self.quote(column)
        else:
            return column

    # Override to search for uppercase keys in grants_table because Netezza always returns
    # uppercase keys and agate.Table.__get_item__ is case-sensitive
    def standardize_grants_dict(self, grants_table: agate.Table) -> dict:
        grants_dict: Dict[str, List[str]] = {}
        for row in grants_table:
            grantee = row["GRANTEE"]
            privilege = row["PRIVILEGE_TYPE"]
            if privilege in grants_dict.keys():
                grants_dict[privilege].append(grantee)
            else:
                grants_dict.update({privilege: [grantee]})
        return grants_dict

    def valid_incremental_strategies(self):
        """The set of standard builtin strategies which this adapter supports out-of-the-box.
        Not used to validate custom strategies defined by end users.
        """
        return ["merge", "delete+insert"]

    # For checking the freshness , converting the str type object returned from netezza relation to datetime
    def calculate_freshness(
        self,
        source: BaseRelation,
        loaded_at_field: str,
        filter: Optional[str],
        macro_resolver: Optional[MacroResolverProtocol] = None,
    ) -> Tuple[Optional[AdapterResponse], Dict[str, Any]]:
        """Calculate the freshness of sources in dbt, and return it"""
        kwargs: Dict[str, Any] = {
            "source": source,
            "loaded_at_field": loaded_at_field,
            "filter": filter,
        }
        # run the macro
        # in older versions of dbt-core, the 'collect_freshness' macro returned the table of results directly
        # starting in v1.5, by default, we return both the table and the adapter response (metadata about the query)
        result: Union[
            AttrDict,  # current: contains AdapterResponse + agate.Table
            agate.Table,  # previous: just table
        ]
        result = self.execute_macro(FRESHNESS_MACRO_NAME, kwargs=kwargs, macro_resolver=macro_resolver)
        if isinstance(result, agate.Table):
            deprecations.warn("collect-freshness-return-signature")
            adapter_response = None
            table = result
        else:
            adapter_response, table = result.response, result.table  # type: ignore[attr-defined]
        # now we have a 1-row table of the maximum `loaded_at_field` value and
        # the current time according to the db.
        if len(table) != 1 or len(table[0]) != 2:
            raise MacroResultError(FRESHNESS_MACRO_NAME, table)
        if table[0][0] is None:
            # no records in the table, so really the max_loaded_at was
            # infinitely long ago. Just call it 0:00 January 1 year UTC
            max_loaded_at = datetime(1, 1, 1, 0, 0, 0, tzinfo=pytz.UTC)
        else:
            max_loaded_at = _utc(parser.parse(table[0][0]), source, loaded_at_field)
        snapshotted_at = _utc(parser.parse(table[0][1]), source, loaded_at_field)
        age = (snapshotted_at - max_loaded_at).total_seconds()
        freshness = {
            "max_loaded_at": max_loaded_at,
            "snapshotted_at": snapshotted_at,
            "age": age,
        }
        return adapter_response, freshness

    @classmethod
    def convert_number_type(cls, agate_table: agate.Table, col_idx: int) -> str:
        # TODO CT-211
        decimals = agate_table.aggregate(agate.MaxPrecision(col_idx))  # type: ignore[attr-defined]
        if decimals :
            return "float8"
        else :
            clm = max([row[col_idx] for row in agate_table.rows])
            if clm >= cls.INT_MIN32 and clm <= cls.INT_MAX32:
                return "integer"
            elif clm > cls.INT_MAX32:
                return "bigint"



from contextlib import contextmanager
from dataclasses import dataclass
from typing import Optional, Tuple, Any
import time

import agate
from dbt_common.clients import agate_helper
from dbt_common.exceptions import DbtRuntimeError, DbtDatabaseError
from dbt.adapters.contracts.connection import Credentials
from dbt.adapters.sql import SQLConnectionManager as connection_cls
from dbt.adapters.events.logging import AdapterLogger
from dbt_common.events.functions import fire_event, warn_or_error
from dbt.adapters.events.types import ConnectionUsed, SQLQuery, SQLQueryStatus, TypeCodeNotFound
from dbt.adapters.contracts.connection import Connection, AdapterResponse
from dbt_common.helper_types import Port
import nzpy


logger = AdapterLogger("Netezza")


@dataclass
class NetezzaCredentials(Credentials):
    """
    Defines database specific credentials that get added to
    profiles.yml to connect to new adapter
    """

    dsn: Optional[str] = None
    username: Optional[str] = None
    password: Optional[str] = None
    database: Optional[str] = None
    schema: Optional[str] = None
    host: Optional[str] = None
    port: Port = Port(5480)
    retries: int = 1

    _ALIASES = {"dbname": "database", "user": "username", "pass": "password"}

    @property
    def type(self):
        """Return name of adapter."""
        return "netezza"

    @property
    def unique_field(self):
        """
        Hashed and included in anonymous telemetry to track adapter adoption.
        Pick a field that can uniquely identify one team/organization building with this adapter
        """
        return self.host

    def _connection_keys(self):
        """
        List of keys to display in the `dbt debug` output.
        """
        return (
            ("dsn", "username")
            if self.dsn
            else ("host", "port", "database", "schema", "username")
        )


class NetezzaConnectionManager(connection_cls):
    TYPE = "netezza"

    @contextmanager
    def exception_handler(self, sql):
        """
        Returns a context manager, that will handle exceptions raised
        from queries, catch, log, and raise dbt exceptions it knows how to handle.
        """
        try:
            yield

        except nzpy.core.ProgrammingError as e:
            logger.error("NZ backend responded with: {}", str(e))
            raise DbtRuntimeError(str(e)) from e

        except nzpy.DatabaseError as e:
            logger.debug("Netezza error: {}", str(e))
            try:
                self.rollback_if_open()
            except nzpy.DatabaseError:
                logger.error("Failed to release connection!")

            _, error_message = e.args
            raise DbtDatabaseError(error_message) from e


        except Exception as e:
            logger.debug("Error running SQL: {}", sql)
            logger.debug("Rolling back transaction.")
            self.rollback_if_open()
            if isinstance(e, DbtRuntimeError):
                # during a sql query, an internal to dbt exception was raised.
                # this sounds a lot like a signal handler and probably has
                # useful information, so raise it without modification.
                raise

            raise DbtRuntimeError(str(e)) from e

    @classmethod
    def open(cls, connection):
        """
        Receives a connection object and a Credentials object
        and moves it to the "open" state.
        """
        if connection.state == "open":
            logger.debug("Connection is already open, skipping open.")
            return connection

        credentials = cls.get_credentials(connection.credentials)

        connection_args = {}
        if credentials.dsn:
            connection_args = {"DSN": credentials.dsn}
        else:
            connection_args = {
                "host": credentials.host,
                "port": credentials.port,
                "database": credentials.database,
                "logOptions": nzpy.LogOptions.Disabled
            }

        def connect():
            handle = nzpy.connect(
                user=credentials.username,
                password=credentials.password,
                **connection_args,
            )
            return handle

        retryable_exceptions = [
            nzpy.OperationalError,
        ]

        return cls.retry_connection(
            connection,
            connect=connect,
            logger=logger,
            retry_limit=credentials.retries,
            retryable_exceptions=retryable_exceptions,
        )

    def cancel(self, connection):
        """
        Gets a connection object and attempts to cancel any ongoing queries.
        """
        connection.handle.close()

    @classmethod
    def get_credentials(cls, credentials):
        return credentials


    @classmethod
    def get_response(cls, cursor) -> AdapterResponse:
        """
        Gets a cursor object and returns adapter-specific information
        about the last executed command generally a AdapterResponse object
        that has items such as code, rows_affected, etc. can also just be a string ex. "OK"
        if your cursor does not offer rich metadata.
        """
        return AdapterResponse("OK", rows_affected=cursor.rowcount)

    # Override to prevent error when calling execute without bindings
    def add_query(
        self,
        sql: str,
        auto_begin: bool = True,
        bindings: Optional[Any] = None,
        abridge_sql_log: bool = False,
    ) -> Tuple[Connection, Any]:
        connection = self.get_thread_connection()
        if auto_begin and connection.transaction_open is False:
            self.begin()
        fire_event(ConnectionUsed(conn_type=self.TYPE, conn_name=connection.name))

        with self.exception_handler(sql):
            if abridge_sql_log:
                log_sql = "{}...".format(sql[:512])
            else:
                log_sql = sql

            fire_event(SQLQuery(conn_name=connection.name, sql=log_sql))
            pre = time.time()

            cursor = connection.handle.cursor()

            # pyodbc cursor will fail if bindings are passed to execute and not needed
            if bindings:
                cursor.execute(sql, bindings)
            else:
                cursor.execute(sql)

            # Get the result of the first non-empty result set (if any)
            while cursor.description is None:
               # if not cursor.nextset():
                break
            fire_event(
                SQLQueryStatus(
                    status=str(self.get_response(cursor)),
                    elapsed=round((time.time() - pre), 2),
                )
            )

            return connection, cursor

    @classmethod
    def data_type_code_to_name(cls, type_code) -> str:
        name_map = {
            "int": "INTEGER",
            "str": "STRING",
            "date": "DATE",
            "datetime": "DATETIME",
            "bool": "BOOLEAN",
            "float": "FLOAT",
        }
        if type_code in name_map:
            return name_map[type_code].name
        else:
            warn_or_error(TypeCodeNotFound(type_code=type_code))
            return f"unknown type_code {type_code}"

    # Override to support multiple queries
    # Source: https://github.com/dbt-msft/dbt-sqlserver/blob/master/dbt/adapters/sqlserver/sql_server_connection_manager.py
    def execute(
        self, sql: str, auto_begin: bool = False, fetch: bool = False, limit: Optional[int] = None
    ) -> Tuple[AdapterResponse, agate.Table]:
        sql = self._add_query_comment(sql)
        _, cursor = self.add_query(sql, auto_begin)
        response = self.get_response(cursor)
        if fetch:
            # Get the result of the first non-empty result set (if any)
            while cursor.description is None:
               # if not cursor.nextset():
                break
            table = self.get_result_from_cursor(cursor, limit)
        else:
            table = agate_helper.empty_table()
        # Step through all result sets so we process all errors
       # while cursor.nextset():
       #     pass
        return response, table



from dbt.adapters.netezza.connections import NetezzaConnectionManager # noqa
from dbt.adapters.netezza.connections import NetezzaCredentials
from dbt.adapters.netezza.impl import NetezzaAdapter

from dbt.adapters.base import AdapterPlugin
from dbt.include import netezza


Plugin = AdapterPlugin(
    adapter=NetezzaAdapter,
    credentials=NetezzaCredentials,
    include_path=netezza.PACKAGE_PATH)



__path__ = __import__('pkgutil').extend_path(__path__, __name__)

import click

from pathlib import Path
from dbt.cli import params as p
from dbt.cli import requires
from dbt.cli.main import cli, global_flags
from dbt.task.init import InitTask
from dbt.events.types import SettingUpProfile, InvalidProfileTemplateYAML
from dbt_common.events.functions import fire_event
from dbt.adapters.netezza.et_options_parser import create_et_options

class NetezzaInitTask(InitTask):
    def setup_profile(self, profile_name: str) -> None:
        """Set up a new profile for a project"""
        fire_event(SettingUpProfile())
        if not self.check_if_can_write_profile(profile_name=profile_name):
            return
        # If a profile_template.yml exists in the project root, that effectively
        # overrides the profile_template.yml for the given target.
        profile_template_path = Path("profile_template.yml")
        if profile_template_path.exists():
            try:
                # This relies on a valid profile_template.yml from the user,
                # so use a try: except to fall back to the default on failure
                self.create_profile_using_project_profile_template(profile_name)
                return
            except Exception:
                fire_event(InvalidProfileTemplateYAML())
        adapter = self.ask_for_adapter_choice()
        if adapter == 'netezza':
            create_et_options('.')
        self.create_profile_from_target(adapter, profile_name=profile_name)

# dbt init
@cli.command("init")
@click.pass_context
@global_flags
# for backwards compatibility, accept 'project_name' as an optional positional argument
@click.argument("project_name", required=False)
@p.profiles_dir_exists_false
@p.project_dir
@p.skip_profile_setup
@p.vars
@requires.postflight
@requires.preflight
def netezza_init(ctx, **kwargs):
    """Initialize a new dbt project for netezza driver."""

    with NetezzaInitTask(ctx.obj["flags"]) as task:
        results = task.run()
        success = task.interpret_results(results)
    return results, success

init = netezza_init
